@@ -1,7 +1,7 @@
 #!/usr/bin/perl -w
 
 package Games::Go::Image2SGF;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 =cut
 
@@ -42,6 +42,11 @@ Required.  The coordinates of the four corners of the go board's grid.  You
 can obtain these by loading your photograph in an image editor that displays 
 image coordinates and hovering the cursor over each of the grid corners. 
 
+=item image 
+
+Required.  The filename of the image to interpret.  This can be in any format 
+supported by I<Imager>.
+
 =item white, black, board
 
 Optional.  A fairly-representative colour for the white stones, black stones, 
@@ -50,19 +55,13 @@ for white.  You should only set these if the generated SGF is incorrect.
 Default:  Black is C<[0,0,0]>, white is C<[255,255,255]>, board colour is 
 C<[100,100,100]>.
 
-=item image 
-
-Required.  The filename of the image to interpret.  This can be in any format 
-supported by I<Imager>.
-
 =item sample_radius
 
 Optional.  After inferring the grid from the corner points you give, the 
 module will search in a radius of C<sample_radius> pixels to look for stones 
 of a particular colour.  As with the C<white, black, board> options:  the 
 default is likely to do the right thing, and you should only increase or 
-decrease it if your image is very large or very small.
-Default:  10 pixels.
+decrease it if your image is very large or very small.  Default:  10 pixels.
 
 =back
 
@@ -95,6 +94,7 @@ use constant WHITE     => 1;
 use constant BLACK     => 2;
 use constant X => 0;
 use constant Y => 1;
+use constant EPSILON => 0.0001;
 
 use strict;
 use Imager;
@@ -160,7 +160,6 @@ sub find_intersections {
     #  Find the equations for the lines connecting the four sides.
     #  Lines are defined by their slope (m) and yintercept (b) with
     #  the line equation:  y = mx + b.
-    
     my $m_left = ($self->{tl}[Y] - $self->{bl}[Y]) /
                  ($self->{tl}[X] - $self->{bl}[X]);
     my $b_left = $self->{bl}[Y] - ($m_left * $self->{bl}[X]);
@@ -182,13 +181,14 @@ sub find_intersections {
     # lines, and a "horizontal vanishing point" (hvp) for top and bottom 
     # intersection. There is the possibility that two lines are perfectly 
     # parallel -- we check this first and create a very small difference if 
-    # they look the same.
-    if ( ($m_left / $m_right) > 0.9999 and ($m_left / $m_right) < 1.0001) {
-      $m_left = 1.0001 * $m_right;
-    }
-    if ( ($m_top / $m_bottom) > 0.9999 and ($m_top / $m_bottom) < 1.0001) {
-      $m_top = 1.0001 * $m_bottom;
-    }
+    # we're going to be generating a SIGFPE. 
+    if ($m_top == $m_bottom) { 
+		$m_top += EPSILON;
+	}
+    if ($m_left == $m_right) {
+		$m_left += EPSILON;
+	}
+
     my $x_vvp = ($b_right - $b_left) / ($m_left - $m_right);
     my $y_vvp = ($m_left * $x_vvp) + $b_left;
     my $x_hvp = ($b_top - $b_bottom) / ($m_bottom - $m_top);
@@ -293,9 +293,8 @@ sub sample {
     for (my $k = ($x_vertex - $radius); $k <= ($x_vertex + $radius); $k++) {
         for (my $l = ($y_vertex - $radius); $l <= ($y_vertex + $radius); $l++) {
              if (($x_vertex - $k)**2 + ($y_vertex - $l)**2 <= ($radius**2)) {
-                # If this is true, then the point ($k, $l) is in our circle.
+				# If this is true, then the point ($k, $l) is in our circle.
                 # Now we sample at it.
-
                 my $gp = $self->{img}->getpixel('x' => $k, 'y' => $l);
                 next if $gp == undef;
                 if (_color_cmp($gp, $black) == 1) { $blackcount++; }
@@ -345,9 +344,7 @@ sub start_sgf {
 (;GM[1]FF[4]SZ[19]
 GN[Image2SGF conversion of $time.]
 
-PC[Image2SGF.]
 AP[Image2SGF by Chris Ball.]
-C[SGF generated by Image2SGF.]
 PL[B]
 ENDSTARTSGF
 }
